% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/enhanceSynopticData.R
\name{enhanceSynopticData}
\alias{enhanceSynopticData}
\title{Enhance synoptic data from Purple Air}
\usage{
enhanceSynopticData(
  pas_raw = NULL,
  countryCodes = c("US"),
  includePWFSL = TRUE
)
}
\arguments{
\item{pas_raw}{Dataframe returned by \code{downloadParseSynopticData()}.}

\item{countryCodes}{ISO country codes used to subset the data.}

\item{includePWFSL}{Logical specifying whether to calculate distances from 
PWFSL monitors.}
}
\value{
Enhanced Dataframe of synoptic PurpleAir data.
}
\description{
Enhance raw synoptic data from PurpleAir to create a generally 
useful dataframe.

Steps include:

1) Replace variable with more consistent, more human readable names.

2) Add spatial metadata for each monitor including:
\itemize{
  \item{timezone -- olson timezone}
  \item{countryCode -- ISO 3166-1 alpha-2}
  \item{stateCode -- ISO 3166-2 alpha-2}
  \item{airDistrict -- CARB air districts}
}

3) Convert data types from character to \code{POSIXct} and \code{numeric}.

4) Add distance and monitorID for the two closest PWFSL monitors

5) Add additional metadata items:
\itemize{
\item{sensorManufacturer = "Purple Air"}
\item{targetPollutant = "PM"}
\item{technologyType = "consumer-grade"}
\item{communityRegion -- (where known)}
}

Subsetting by country may be performed by specifying the \code{countryCodes} 
argument.

Setting \code{outsideOnly = TRUE} will return only those records marked as 
'outside'.
}
\note{
For data obtained on July 28, 2018 this will result in removal of all 
'B' channels, even those whose parent 'A' channel is marked as 'outside'. 
This is useful if you want a quick, synoptic view of the network, e.g. for a 
map.
}
\examples{
\dontrun{
initializeMazamaSpatialUtils()
pas_raw <- downloadParseSynopticData()
pas <- enhanceSynopticData(pas_raw)
setdiff(names(pas), names(pas_raw))
View(pas[1:100,])
}
}
\seealso{
\link{downloadParseSynopticData}
}
